Installation — oceanum 0.1.0 documentation

# Installation

## Using pip

To install oceanum, run this command in your terminal:

    $ pip install oceanum

This is the preferred method to install oceanum, as it will always install the most recent stable release.

If you don’t have pip installed, this Python installation guide can guide you through the process.

## From sources

The sources for oceanum can be downloaded from the Github repo.

You can either clone the public repository:

    $ git clone git://github.com/oceanum/oceanum-python

Or download the tarball:

    $ curl  -OL https://github.com/oceanum/oceanum-python/tarball/master

Once you have a copy of the source, you can install it with:

    $ python setup.py install

previous

Oceanum python library

next

Usage